@@ -3,9 +3,9 @@ import time
 
 import cv2
 import numpy as np
-import pyautogui
 
 from smb3_eh_manip.settings import config, get_config_region
+from smb3_eh_manip.fceux_lua_server import *
 from smb3_eh_manip.video_player import VideoPlayer
 
 CLEAR_SIGHTING_DURATION_SECONDS = 10
@@ -23,6 +23,7 @@ class OpencvComputer:
         self.player_window_title = player_window_title
         self.start_frame_image_path = start_frame_image_path
         self.start_frame_image_region = start_frame_image_region
+        self.video_offset_frames = video_offset_frames
         self.show_capture_video = config.getboolean("app", "show_capture_video")
         self.autoreset = config.getboolean("app", "autoreset")
         self.enable_fceux_tas_start = config.getboolean("app", "enable_fceux_tas_start")
@@ -60,6 +61,8 @@ class OpencvComputer:
         self.end_stage_clear_text_region = get_config_region(
             "app", "end_stage_clear_text_region"
         )
+        if self.enable_fceux_tas_start:
+            waitForFceuxConnection()
 
     def tick(self):
         self.current_time = time.time()
@@ -100,13 +103,8 @@ class OpencvComputer:
             if self.enable_video_player:
                 self.video_player.reset()
             if self.enable_fceux_tas_start:
-                pyautogui.press("pause")
-                # TODO need to pause, rewind, increment forward TAS
-                # time.sleep(0.001)
-                # with pyautogui.hold("shift"):
-                #    pyautogui.press("pageup")
-                # for _i in range(offset):
-                #    pyautogui.press("backslash")
+                emu.pause()
+                taseditor.setplayback(self.video_offset_frames)
             logging.info(f"Detected reset")
         if not self.playing:
             results = list(
@@ -123,7 +121,7 @@ class OpencvComputer:
                 self.playing = True
                 self.start_time = time.time()
                 if self.enable_fceux_tas_start:
-                    pyautogui.press("pause")
+                    emu.unpause()
                 if self.enable_video_player:
                     self.video_player.play()
                 logging.info(f"Detected start frame")
@@ -132,7 +130,8 @@ class OpencvComputer:
         cv2.waitKey(1)
 
     def terminate(self):
-        self.video_player.terminate()
+        if self.video_player:
+            self.video_player.terminate()
         if self.write_capture_video:
             self.output_video.release()
         self.capture.release()
